@@ -26,7 +26,7 @@ class IButtonTextSchema(model.Schema):
 
     button_text = schema.TextLine(
         title=_(u'Button text'),
-        required=True,
+        required=False,
         defaultFactory=default_button_text,
     )
 
